@@ -1,7 +1,7 @@
 """Licensed under GPLv3, see https://www.gnu.org/licenses/"""
 
 from multiprocessing.pool import ThreadPool
-from typing import TYPE_CHECKING, Any, Final
+from typing import TYPE_CHECKING
 from urllib import parse
 from urllib.parse import quote
 
@@ -12,10 +12,18 @@ from .progressbar import ThreadSafeProgressBar
 from .urllib import get_gzip_from_url, get_json_from_url
 
 if TYPE_CHECKING:
+    from typing import Any, Final
+
     from .srcinfo import SrcInfo
 
 
-MAX_URL_LENGTH: Final = 8177  # default value in many web servers
+MAX_URL_LENGTH: "Final" = 8177  # default value in many web servers
+
+
+class AurRPCErrors:
+    ERROR_KEY: "Final" = "error"
+    TOO_MANY_RESULTS: "Final" = "Too many package results."
+    QUERY_TOO_SMALL: "Final" = "Query arg too small."
 
 
 class AurBaseUrl:
@@ -61,11 +69,11 @@ class AURPackageInfo(DataType):
     def git_url(self) -> str:
         return f"{AurBaseUrl.get()}/{self.packagebase}.git"
 
-    def __init__(self, **kwargs: Any) -> None:
+    def __init__(self, **kwargs: "Any") -> None:
         for aur_api_name, pikaur_class_name in (
-            ("description", "desc", ),
-            ("id", "aur_id", ),
-            ("license", "pkg_license", ),
+            ("description", "desc"),
+            ("id", "aur_id"),
+            ("license", "pkg_license"),
         ):
             if aur_api_name in kwargs:
                 kwargs[pikaur_class_name] = kwargs.pop(aur_api_name)
@@ -89,7 +97,7 @@ class AURPackageInfo(DataType):
                     "replaces",
                     "provides",
                 ]
-            }
+            },
         )
 
     def __repr__(self) -> str:
@@ -118,15 +126,15 @@ def aur_rpc_search_name_desc(search_query: str) -> list[AURPackageInfo]:
         "v": 5,
         "type": "search",
         "arg": strip_aur_repo_name(search_query),
-        "by": "name-desc"
+        "by": "name-desc",
     })
     result_json = get_json_from_url(url)
-    if "error" in result_json:
-        raise AURError(url=url, error=result_json["error"])
+    if AurRPCErrors.ERROR_KEY in result_json:
+        raise AURError(url=url, error=result_json[AurRPCErrors.ERROR_KEY])
     return [
         AURPackageInfo(
             **{key.lower(): value for key, value in aur_json.items()},
-            ignore_extra_properties=True
+            ignore_extra_properties=True,
         )
         for aur_json in result_json.get("results", [])
     ]
@@ -145,19 +153,19 @@ def _get_aur_rpc_info_url(search_queries: list[str]) -> str:
 def aur_rpc_info(search_queries: list[str]) -> list[AURPackageInfo]:
     url = _get_aur_rpc_info_url(search_queries=search_queries)
     result_json = get_json_from_url(url)
-    if "error" in result_json:
-        raise AURError(url=url, error=result_json["error"])
+    if AurRPCErrors.ERROR_KEY in result_json:
+        raise AURError(url=url, error=result_json[AurRPCErrors.ERROR_KEY])
     return [
         AURPackageInfo(
             **{key.lower(): value for key, value in aur_json.items()},
-            ignore_extra_properties=True
+            ignore_extra_properties=True,
         )
         for aur_json in result_json.get("results", [])
     ]
 
 
 def aur_rpc_info_with_progress(
-        search_queries: list[str], *, progressbar_length: int, with_progressbar: bool
+        search_queries: list[str], *, progressbar_length: int, with_progressbar: bool,
 ) -> list[AURPackageInfo]:
     result = aur_rpc_info(search_queries)
     if with_progressbar:
@@ -202,7 +210,7 @@ def get_max_pkgs_chunks(package_names: list[str]) -> list[list[str]]:
     chunk: list[str] = []
     pkgs_to_do = package_names[::]
     while pkgs_to_do:
-        if len(_get_aur_rpc_info_url(chunk + [pkgs_to_do[0]])) < MAX_URL_LENGTH:
+        if len(_get_aur_rpc_info_url([*chunk, pkgs_to_do[0]])) < MAX_URL_LENGTH:
             chunk.append(pkgs_to_do.pop(0))
         else:
             chunks.append(chunk)
@@ -213,7 +221,7 @@ def get_max_pkgs_chunks(package_names: list[str]) -> list[list[str]]:
 
 
 def find_aur_packages(
-        package_names: list[str], *, with_progressbar: bool = False
+        package_names: list[str], *, with_progressbar: bool = False,
 ) -> tuple[list[AURPackageInfo], list[str]]:
 
     # @TODO: return only packages for the current architecture
@@ -233,7 +241,7 @@ def find_aur_packages(
                 pool.apply_async(aur_rpc_info_with_progress, [], {
                     "search_queries": chunk,
                     "progressbar_length": len(search_chunks),
-                    "with_progressbar": with_progressbar
+                    "with_progressbar": with_progressbar,
                 })
                 for chunk in search_chunks
             ]
