@@ -2,10 +2,14 @@
 
 import sys
 from threading import Lock
-from typing import Any, Callable
+from typing import TYPE_CHECKING
 
 from .pprint import color_enabled, get_term_width
 
+if TYPE_CHECKING:
+    from collections.abc import Callable
+    from typing import Any, Final
+
 
 class ProgressBar():
 
@@ -13,10 +17,10 @@ class ProgressBar():
     index = 0
     progress = 0
 
-    LEFT_DECORATION = "["
-    RIGHT_DECORATION = "]"
-    EMPTY = "-"
-    FULL = "#"
+    LEFT_DECORATION: "Final" = "["
+    RIGHT_DECORATION: "Final" = "]"
+    EMPTY: "Final" = "-"
+    FULL: "Final" = "#"
 
     def __init__(self, length: int, message: str = "") -> None:
         width = (
@@ -35,10 +39,10 @@ class ProgressBar():
             if color_enabled():
                 sys.stderr.write(self.FULL)
 
-    def __enter__(self) -> Callable[[], None]:
+    def __enter__(self) -> "Callable[[], None]":
         return self.update
 
-    def __exit__(self, *_exc_details: Any) -> None:
+    def __exit__(self, *_exc_details: "Any") -> None:
         sys.stderr.write("\n")
 
 
@@ -55,6 +59,6 @@ class ThreadSafeProgressBar():
                     sys.stderr.write("\n")
                     cls._progressbar_storage[progressbar_id] = ProgressBar(
                         length=progressbar_length,
-                        message="Synchronizing AUR database... "
+                        message="Synchronizing AUR database... ",
                     )
         return cls._progressbar_storage[progressbar_id]
